@@ -87,7 +87,7 @@ cindex_survmat <- function(object, predicted, t_star = NULL) {
 #' @param pre_sp A numeric vector of predicted survival probabilities at `t_star`.
 #' @param t_star The evaluation time point.
 #'
-#' @return A single numeric value representing the Brier score.
+#' @return A single numeric value representing the Brier score a a specific time point.
 #' @export
 #'
 #' @examples
@@ -140,8 +140,6 @@ brier <- function(object, pre_sp, t_star) {
 }
 
 
-
-
 #' Integrated Brier Score (IBS) from a Survival Probability Matrix
 #'
 #' Computes the Integrated Brier Score (IBS) over a set of evaluation time points,
@@ -183,7 +181,7 @@ ibs_survmat <- function(object, sp_matrix, times) {
   }, numeric(1))
 
   dt <- diff(times)
-  integral <- sum(brier_vec[-length(brier_vec)] * dt)
+  integral <- sum((brier_vec[-1] + brier_vec[-length(brier_vec)]) / 2 * dt)
   ibs_value <- integral / (max(times) - min(times))
   names(ibs_value) <- "ibs"
   return(round(ibs_value, 6))
