@@ -29,18 +29,19 @@ utils::globalVariables(c("loss", "epoch"))
 #'
 #' @return A tibble or model object depending on the `return` value.
 #' @export
-tune_survdnn <- function(formula,
-                         data,
-                         times,
-                         metrics = "cindex",
-                         param_grid,
-                         folds = 3,
-                         .seed = 42,
-                         .device = c("auto", "cpu", "cuda"),
-                         na_action = c("omit", "fail"),
-                         refit = FALSE,
-                         return = c("all", "summary", "best_model")) {
-
+tune_survdnn <- function(
+  formula,
+  data,
+  times,
+  metrics = "cindex",
+  param_grid,
+  folds = 3,
+  .seed = 42,
+  .device = c("auto", "cpu", "cuda"),
+  na_action = c("omit", "fail"),
+  refit = FALSE,
+  return = c("all", "summary", "best_model")
+) {
   return    <- match.arg(return)
   .device   <- match.arg(.device)
   na_action <- match.arg(na_action)
@@ -52,7 +53,6 @@ tune_survdnn <- function(formula,
   all_results <- purrr::pmap_dfr(
     param_df,
     function(hidden, lr, activation, epochs, loss) {
-
       config_tbl <- tibble::tibble(
         hidden     = list(hidden),
         lr         = lr,
@@ -62,13 +62,13 @@ tune_survdnn <- function(formula,
       )
 
       cv_tbl <- cv_survdnn(
-        formula   = formula,
-        data      = data,
-        times     = times,
-        metrics   = metrics,
-        folds     = folds,
-        hidden    = hidden,
-        lr        = lr,
+        formula    = formula,
+        data       = data,
+        times      = times,
+        metrics    = metrics,
+        folds      = folds,
+        hidden     = hidden,
+        lr         = lr,
         activation = activation,
         epochs     = epochs,
         loss       = loss,
@@ -83,7 +83,7 @@ tune_survdnn <- function(formula,
 
   summary_tbl <- summarize_tune_survdnn(all_results, by_time = FALSE)
 
-  ## Select best hyperparameters
+  ## select best hyperparameters
   primary_metric <- metrics[1]
 
   best_row_all <- all_results |>
@@ -91,7 +91,7 @@ tune_survdnn <- function(formula,
     dplyr::group_by(hidden, lr, activation, epochs, loss) |>
     dplyr::summarise(mean = mean(value, na.rm = TRUE), .groups = "drop") |>
     dplyr::slice_max(
-      order_by = if (primary_metric == "cindex") mean else -mean,
+      order_by = if (identical(primary_metric, "cindex")) mean else -mean,
       n = 1
     )
 
@@ -99,7 +99,7 @@ tune_survdnn <- function(formula,
     stop("No valid configuration found for primary metric: ", primary_metric, call. = FALSE)
   }
 
-  ## Refitting the best model
+  ## refitting the best model
   if (refit) {
     message("Refitting best model on full data...")
     best_model <- survdnn(
